Functions for determining the network interface when connecting to NervesHub and downloading firmware.
Summary
Functions
Get the network interface from a Slipstream.Socket or Mint.HTTP struct. This is used to report the network interface being used for the connection to NervesHub and for firmware downloads.
Functions
@spec from_socket( :ssl.socket() | :inet.socket() | :socket.socket() | Mint.Types.socket() ) :: nil | binary()
Get the network interface from a Slipstream.Socket or Mint.HTTP struct. This is used to report the network interface being used for the connection to NervesHub and for firmware downloads.